@@ -26,11 +26,11 @@
 setConstructorS3("CnProbeAffinityFile", function(..., combineAlleles=FALSE) {
   this <- extend(SnpProbeAffinityFile(...), "CnProbeAffinityFile",
     combineAlleles=combineAlleles
-  );
+  )
 
   setAttributesByTags(this)
 
-  this;
+  this
 })
 
 
@@ -64,33 +64,33 @@ setConstructorS3("CnProbeAffinityFile", function(..., combineAlleles=FALSE) {
 #*/###########################################################################
 setMethodS3("getCellIndices", "CnProbeAffinityFile", function(this, ..., unlist=FALSE) {
   # Argument 'unlist':
-  unlist <- Arguments$getLogical(unlist);
+  unlist <- Arguments$getLogical(unlist)
 
 
   # Supported case?
-  combineAlleles <- this$combineAlleles;
+  combineAlleles <- this$combineAlleles
   if (unlist && combineAlleles) {
-    throw("Unsupported request: Argument 'unlist' have to be TRUE when parameter 'combineAlleles' is TRUE: ", unlist);
+    throw("Unsupported request: Argument 'unlist' have to be TRUE when parameter 'combineAlleles' is TRUE: ", unlist)
   }
 
 
-  cells <- NextMethod("getCellIndices");
+  cells <- NextMethod("getCellIndices")
 
   # If combining alleles, return only every second group.
   # In order to improve readability we merge the names of alleles groups
   # combined, e.g. groups 'C' and 'G' become group 'CG'.
   if (combineAlleles) {
     cells <- .applyCdfGroups(cells, function(groups) {
-      ngroups <- length(groups);
-      odds <- seq(from=1L, to=ngroups, by=2L);
-      names <- names(groups);
-      groups <- groups[odds];
+      ngroups <- length(groups)
+      odds <- seq(from=1L, to=ngroups, by=2L)
+      names <- names(groups)
+      groups <- groups[odds]
       if (ngroups >= 2L) {
-        evens <- seq(from=2L, to=ngroups, by=2L);
-        names <- paste(names[odds], names[evens], sep="");
-        names(groups) <- names;
+        evens <- seq(from=2L, to=ngroups, by=2L)
+        names <- paste(names[odds], names[evens], sep="")
+        names(groups) <- names
       }
-      groups;
+      groups
     })
   } # if (combineAlleles)
 
@@ -99,22 +99,13 @@ setMethodS3("getCellIndices", "CnProbeAffinityFile", function(this, ..., unlist=
   # Unlist?
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (unlist) {
-    cells <- unlist(cells, use.names=FALSE);
+    cells <- unlist(cells, use.names=FALSE)
   }
 
-  cells;
+  cells
 }, protected=TRUE) # getCellIndices()
 
 
 setMethodS3("setCombineAlleles", "CnProbeAffinityFile", function(this, status, ...) {
-  this$combineAlleles <- status;
+  this$combineAlleles <- status
 }, protected=TRUE)
-
-
-############################################################################
-# HISTORY:
-# 2006-09-12
-# o Updated.
-# 2006-09-11
-# o Created.
-############################################################################
