@@ -33,52 +33,52 @@ setConstructorS3("CnagCfhFile", function(..., cdf=NULL) {
   )
 
   if (!is.null(cdf))
-    setCdf(this, cdf);
+    setCdf(this, cdf)
 
   # Parse attributes (all subclasses must call this in the constructor).
   setAttributesByTags(this)
 
-  this;
+  this
 })
 
 
 setMethodS3("clone", "CnagCfhFile", function(this, ..., verbose=TRUE) {
   # Clone itself (and clear the cached fields)
-  object <- NextMethod("clone", clear=TRUE);
+  object <- NextMethod("clone", clear=TRUE)
 
   # Clone the CDF here.
   if (!is.null(object$.cdf))
-    object$.cdf <- clone(object$.cdf);
+    object$.cdf <- clone(object$.cdf)
 
-  object;
+  object
 }, protected=TRUE)
 
 
 setMethodS3("as.character", "CnagCfhFile", function(x, ...) {
   # To please R CMD check
-  this <- x;
+  this <- x
 
-  s <- NextMethod("as.character");
-  s <- c(s, sprintf("Chip type: %s", getChipType(getCdf(this))));
-  s <- c(s, sprintf("Timestamp: %s", as.character(getTimestamp(this))));
-  s;
+  s <- NextMethod("as.character")
+  s <- c(s, sprintf("Chip type: %s", getChipType(getCdf(this))))
+  s <- c(s, sprintf("Timestamp: %s", as.character(getTimestamp(this))))
+  s
 }, protected=TRUE)
 
 
 setMethodS3("getExtensionPattern", "CnagCfhFile", function(static, ...) {
-  "[.](cfh|CFH)$";
+  "[.](cfh|CFH)$"
 }, static=TRUE, protected=TRUE)
 
 
 
 
 setMethodS3("getIdentifier", "CnagCfhFile", function(this, ..., force=FALSE) {
-  id <- this$.identifier;
+  id <- this$.identifier
   if (force || is.null(id)) {
-    id <- getChecksum(this);
-    this$.identifier <- id;
+    id <- getChecksum(this)
+    this$.identifier <- id
   }
-  id;
+  id
 }, private=TRUE)
 
 
@@ -114,37 +114,37 @@ setMethodS3("getIdentifier", "CnagCfhFile", function(this, ..., force=FALSE) {
 #*/###########################################################################
 setMethodS3("fromFile", "CnagCfhFile", function(static, filename, path=NULL, ..., verbose=FALSE, .checkArgs=TRUE) {
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
   if (.checkArgs) {
     # Argument 'filename' and 'path':
-    pathname <- Arguments$getReadablePathname(filename, path=path, mustExist=TRUE);
+    pathname <- Arguments$getReadablePathname(filename, path=path, mustExist=TRUE)
   } else {
-    pathname <- filename;
+    pathname <- filename
   }
 
 
   readString <- function(con, ...) {
-    len <- readBin(con, what=integer(), size=1, n=1);
-    s <- readBin(con, what=raw(), n=len);
-    s <- rawToChar(s);
-    s;
-  } # readString();
+    len <- readBin(con, what=integer(), size=1, n=1)
+    s <- readBin(con, what=raw(), n=len)
+    s <- rawToChar(s)
+    s
+  } # readString()
 
-  con <- file(pathname, open="rb");
-  on.exit(close(con));
+  con <- file(pathname, open="rb")
+  on.exit(close(con))
 
-  magic <- readString(con);
+  magic <- readString(con)
   if (!identical(magic, "1.001")) {
-    throw("Could not read CPH file. File format error: ", pathname);
+    throw("Could not read CPH file. File format error: ", pathname)
   }
 
   # Create a new instance of the same class
-  newInstance(static, pathname);
+  newInstance(static, pathname)
 }, static=TRUE, protected=TRUE)
 
 
@@ -176,13 +176,13 @@ setMethodS3("fromFile", "CnagCfhFile", function(static, filename, path=NULL, ...
 # @keyword IO
 #*/###########################################################################
 setMethodS3("getCdf", "CnagCfhFile", function(this, ...) {
-  cdf <- this$.cdf;
+  cdf <- this$.cdf
   if (is.null(cdf)) {
-    chipType <- getHeader(this)$chipType;
-    cdf <- AffymetrixCdfFile$byChipType(chipType);
-    this$.cdf <- cdf;
+    chipType <- getHeader(this)$chipType
+    cdf <- AffymetrixCdfFile$byChipType(chipType)
+    this$.cdf <- cdf
   }
-  cdf;
+  cdf
 })
 
 
@@ -216,25 +216,25 @@ setMethodS3("getCdf", "CnagCfhFile", function(this, ...) {
 setMethodS3("setCdf", "CnagCfhFile", function(this, cdf, ..., .checkArgs=TRUE) {
   if (.checkArgs) {
     # Argument 'cdf':
-    cdf <- Arguments$getInstanceOf(cdf, "AffymetrixCdfFile");
+    cdf <- Arguments$getInstanceOf(cdf, "AffymetrixCdfFile")
 
     # Assure that the CDF is compatible with the CEL file
 #    if (nbrOfCells(cdf) != nbrOfCells(this)) {
-#      throw("Cannot set CDF. The specified CDF structure ('", getChipType(cdf), "') is not compatible with the chip type ('", getChipType(this), "') of the CEL file. The number of cells do not match: ", nbrOfCells(cdf), " != ", nbrOfCells(this));
+#      throw("Cannot set CDF. The specified CDF structure ('", getChipType(cdf), "') is not compatible with the chip type ('", getChipType(this), "') of the CEL file. The number of cells do not match: ", nbrOfCells(cdf), " != ", nbrOfCells(this))
 #    }
 
     # Nothing to do?
-#    oldCdf <- getCdf(this);
+#    oldCdf <- getCdf(this)
 #    if (equals(cdf, oldCdf))
-#      return(invisible(this));
+#      return(invisible(this))
   }
 
   # Have to clear the cache
-  clearCache(this);
+  clearCache(this)
 
-  this$.cdf <- cdf;
+  this$.cdf <- cdf
 
-  invisible(this);
+  invisible(this)
 })
 
 
@@ -265,12 +265,12 @@ setMethodS3("setCdf", "CnagCfhFile", function(this, cdf, ..., .checkArgs=TRUE) {
 # @keyword IO
 #*/###########################################################################
 setMethodS3("getHeader", "CnagCfhFile", function(this, ...) {
-  header <- this$.header;
+  header <- this$.header
   if (is.null(header)) {
-    header <- readCfhHeader(getPathname(this), ...);
-    this$.header <- header;
+    header <- readCfhHeader(getPathname(this), ...)
+    this$.header <- header
   }
-  header;
+  header
 }, private=TRUE)
 
 
@@ -278,37 +278,37 @@ setMethodS3("getHeader", "CnagCfhFile", function(this, ...) {
 
 setMethodS3("getHeaderLength", "CnagCfhFile", function(this, ...) {
   nbrOfBytes <- getFileSize(this)
-  nbrOfSnps <- nbrOfSnps(this);
-  dataOffset <- nbrOfBytes %% nbrOfSnps;
-  bytesPerSnp <- nbrOfBytes %/% nbrOfSnps;
-  dataOffset;
-}, private=TRUE);
+  nbrOfSnps <- nbrOfSnps(this)
+  dataOffset <- nbrOfBytes %% nbrOfSnps
+  bytesPerSnp <- nbrOfBytes %/% nbrOfSnps
+  dataOffset
+}, private=TRUE)
 
 
 setMethodS3("nbrOfSnps", "CnagCfhFile", function(this, ...) {
-  nbrOfSnps(getCdf(this));
+  nbrOfSnps(getCdf(this))
 })
 
 
 setMethodS3("getTimestamp", "CnagCfhFile", function(this, format="%m/%d/%y %H:%M:%S", ...) {
   # Argument 'format':
-  format <- Arguments$getCharacter(format, length=c(1,1));
+  format <- Arguments$getCharacter(format, length=c(1,1))
 
   # Get the CEL v3 header of the CEL header
-  header <- getHeader(this);
+  header <- getHeader(this)
 
   # Get the DAT header
-  timeStamp <- header$timeStamp;
+  timeStamp <- header$timeStamp
   if (is.null(timeStamp))
-    timeStamp <- NA;
+    timeStamp <- NA
 
-  timeStamp;
+  timeStamp
 }, private=TRUE)
 
 
 
 setMethodS3("nbrOfCells", "CnagCfhFile", function(this, ...) {
-  as.integer(NA);
+  as.integer(NA)
 })
 
 
@@ -338,7 +338,7 @@ setMethodS3("nbrOfCells", "CnagCfhFile", function(this, ...) {
 # @keyword IO
 #*/###########################################################################
 setMethodS3("getChipType", "CnagCfhFile", function(this, ...) {
-  getChipType(getCdf(this));
+  getChipType(getCdf(this))
 }, private=TRUE)
 
 
@@ -379,87 +379,60 @@ setMethodS3("getChipType", "CnagCfhFile", function(this, ...) {
 #*/###########################################################################
 setMethodS3("readUnits", "CnagCfhFile", function(this, units=NULL, ..., verbose=FALSE) {
   # Argument 'units':
-  cdf <- getCdf(this);
+  cdf <- getCdf(this)
   if (!is.null(units)) {
     # A zero-offset index? /HB 2010-01-01
-    units <- Arguments$getIndices(units, range=c(0, nbrOfUnits(cdf)));
+    units <- Arguments$getIndices(units, range=c(0, nbrOfUnits(cdf)))
   }
 
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Retrieve data
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  offset <- getHeaderLength(this);
-  nbrOfSnps <- nbrOfSnps(this);
-  bytesPerSnp <- 13;
-  nbrOfBytes <- bytesPerSnp*nbrOfSnps;
-  map <- offset + matrix(1:nbrOfBytes, nrow=bytesPerSnp);
+  offset <- getHeaderLength(this)
+  nbrOfSnps <- nbrOfSnps(this)
+  bytesPerSnp <- 13
+  nbrOfBytes <- bytesPerSnp*nbrOfSnps
+  map <- offset + matrix(1:nbrOfBytes, nrow=bytesPerSnp)
 
   # Read subset of units
   if (!is.null(units)) {
-    snps <- indexOf(cdf, "SNP_");
+    snps <- indexOf(cdf, "SNP_")
     # Map unit indices to CNAG SNP indices
-    idxs <- match(units, snps);
-    idxs <- na.omit(idxs);
+    idxs <- match(units, snps)
+    idxs <- na.omit(idxs)
     # Subset of SNPs to read
-    map <- map[,idxs,drop=FALSE];
+    map <- map[,idxs,drop=FALSE]
   }
 
   # Read from file
-  pathname <- getPathname(this);
-  raw <- readBin(pathname, what=raw(), n=nbrOfBytes);
+  pathname <- getPathname(this)
+  raw <- readBin(pathname, what=raw(), n=nbrOfBytes)
 
   # Bytes 1:8 contains (thetaA,thetaB) as floats
-  map <- map[1:8,,drop=FALSE];
+  map <- map[1:8,,drop=FALSE]
   theta <- readBin(raw[map], what=double(), size=4, endian="little",
-                                                           n=2*ncol(map));
-  theta <- matrix(theta, ncol=2, byrow=TRUE);
+                                                           n=2*ncol(map))
+  theta <- matrix(theta, ncol=2, byrow=TRUE)
 
   # Remap according to units
   if (!is.null(units)) {
-    idxs <- match(snps[idxs], units);
-    naValue <- as.double(NA);
-    tmp <- matrix(naValue, ncol=2, nrow=length(units));
-    tmp[idxs,] <- theta;
-    theta <- tmp;
+    idxs <- match(snps[idxs], units)
+    naValue <- as.double(NA)
+    tmp <- matrix(naValue, ncol=2, nrow=length(units))
+    tmp[idxs,] <- theta
+    theta <- tmp
   }
 
-  colnames(theta) <- c("A", "B");
+  colnames(theta) <- c("A", "B")
 
-  theta;
+  theta
 }, private=TRUE)
 
 
 setMethodS3("range", "CnagCfhFile", function(this, ..., na.rm=TRUE) {
-  x <- readDataFrame(this, ...);
-  range(x, na.rm=na.rm);
+  x <- readDataFrame(this, ...)
+  range(x, na.rm=na.rm)
 }, protected=TRUE)
-
-
-
-############################################################################
-# HISTORY:
-# 2013-05-22
-# o CLEANUP: Now getIdentifier() for CnagCfhFile utilizes getChecksum()
-#   for the GenericDataFile class.
-# 2012-11-20
-# o CLEANUP: Deprecated "[" and "[[", because they should be used to
-#   subset files and not units.
-# 2011-02-24
-# o BACKWARD COMPATILITY: getIdentifier() for CnagCfhFile generates
-#   a checksum id based on the relative pathname.  For now, we simply
-#   drop any tags from the root path such that it is compatible with
-#   earlier version of aroma.*.
-# 2008-07-20
-# o Updated the following methods to preallocate matrixes with the correct
-#   data type to avoid coercing later: readUnits().
-# 2008-05-09
-# o Now CnagCfhFile inherits from AromaMicroarrayDataFile.
-# 2007-06-11
-# o BUG FIX: readUnits() of CnagCfhFile was broken because it used the
-#   non-existing variable 'nbrOfBytes'.
-# 2007-04-05
-# o Created.
-############################################################################
