@@ -47,27 +47,27 @@ setConstructorS3("MbeiPlm", function(...) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Load required packages
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  args <- list(...);
+  args <- list(...)
   if (length(args) > 0 && !is.null(args[[1]])) {
     # Early error, iff package not installed.
-    requireNamespace("affy") || throw("Package not loaded: affy");
+    requireNamespace("affy") || throw("Package not loaded: affy")
   }
 
-  this <- extend(ProbeLevelModel(...), "MbeiPlm");
-  validate(this);
-  this;
+  this <- extend(ProbeLevelModel(...), "MbeiPlm")
+  validate(this)
+  this
 })
 
 
 setMethodS3("getAsteriskTags", "MbeiPlm", function(this, collapse=NULL, ...) {
   # Returns 'PLM[,<shift>]'
-  tags <- NextMethod("getAsteriskTags", collapse=NULL);
-  tags[1] <- "MBEI";
+  tags <- NextMethod("getAsteriskTags", collapse=NULL)
+  tags[1] <- "MBEI"
 
   # Collapse
-  tags <- paste(tags, collapse=collapse);
+  tags <- paste(tags, collapse=collapse)
 
-  tags;
+  tags
 }, protected=TRUE)
 
 
@@ -75,7 +75,7 @@ setMethodS3("getProbeAffinityFile", "MbeiPlm", function(this, ...) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Get the probe affinities (and create files etc)
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  paf <- NextMethod("getProbeAffinityFile");
+  paf <- NextMethod("getProbeAffinityFile")
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Update the encode and decode functions
@@ -83,20 +83,20 @@ setMethodS3("getProbeAffinityFile", "MbeiPlm", function(this, ...) {
   setEncodeFunction(paf, function(groupData, ...) {
     # Rename some fields so that we support the structure of this class,
     # but also output from affy::fit.li.wong().
-    names <- names(groupData);
+    names <- names(groupData)
     # Is it an affy:fit.li.wong() structure?
     if ("sdPhi" %in% names) {
-      names <- sub("iter", "nbrOfIterations", names);
-      names <- sub("convergence1", "converged", names);
-      names <- sub("convergence2", "convergedOutliers", names);
-      names(groupData) <- names;
+      names <- sub("iter", "nbrOfIterations", names)
+      names <- sub("convergence1", "converged", names)
+      names <- sub("convergence2", "convergedOutliers", names)
+      names(groupData) <- names
     }
 
     # Encode outliers as the sign of 'pixels'; -1 = TRUE, +1 = FALSE
-    pixels <- sign(0.5 - as.integer(groupData$phiOutliers));
+    pixels <- sign(0.5 - as.integer(groupData$phiOutliers))
 
     # Encode the number of iterations as the absolute value of the 1st pixel.
-    pixels[1] <- pixels[1]*groupData$nbrOfIterations;
+    pixels[1] <- pixels[1]*groupData$nbrOfIterations
 
     # Encode convergence1/2 as bits in the 2nd pixel.
     # Note: For this to work, there must be at least two 'pixels' in the
@@ -111,34 +111,34 @@ setMethodS3("getProbeAffinityFile", "MbeiPlm", function(this, ...) {
     # probe affinities should multiply to one.  There is no standard
     # deviation estimate or convergence results for such single-probe
     # models. /HB 2006-12-18
-    npixels <- length(pixels);
+    npixels <- length(pixels)
     if (npixels > 1) {
       pixels[2] <- pixels[2] *
-              (1 + 2*groupData$converged + 4*groupData$convergedOutliers);
+              (1 + 2*groupData$converged + 4*groupData$convergedOutliers)
     }
 
-    list(intensities=groupData$phi, stdvs=groupData$sdPhi, pixels=pixels);
+    list(intensities=groupData$phi, stdvs=groupData$sdPhi, pixels=pixels)
   })
 
   setDecodeFunction(paf,  function(groupData, ...) {
-    pixels <- groupData$pixels;
+    pixels <- groupData$pixels
 
     # Outliers are encoded by the sign of 'pixels'.
-    outliers <- as.logical(1-sign(pixels));
+    outliers <- as.logical(1-sign(pixels))
 
     # Number of iterations is encoded as the absolute value of the 1st pixel.
-    nbrOfIterations <- as.integer(abs(pixels[1])+0.5);
+    nbrOfIterations <- as.integer(abs(pixels[1])+0.5)
 
-    npixels <- length(pixels);
+    npixels <- length(pixels)
     if (npixels > 1) {
       # convergence & convergenceOutliers are encoded as bits in the 2nd pixel.
-      t <- pixels[2] %/% 2;
-      converged <- as.logical(t %% 2 == 1);  t <- t %/% 2;
-      convergedOutliers <- as.logical(t %% 2 == 1);
+      t <- pixels[2] %/% 2
+      converged <- as.logical(t %% 2 == 1);  t <- t %/% 2
+      convergedOutliers <- as.logical(t %% 2 == 1)
     } else {
       # See comments on the encode function above. /HB 2006-12-18
-      converged <- TRUE;
-      convergedOutliers <- TRUE;
+      converged <- TRUE
+      convergedOutliers <- TRUE
     }
 
     list(
@@ -148,10 +148,10 @@ setMethodS3("getProbeAffinityFile", "MbeiPlm", function(this, ...) {
       nbrOfIterations=nbrOfIterations,
       converged=converged,
       convergedOutliers=convergedOutliers
-    );
+    )
   })
 
-  paf;
+  paf
 }, private=TRUE)
 
 
@@ -182,45 +182,45 @@ setMethodS3("getProbeAffinityFile", "MbeiPlm", function(this, ...) {
 #*/###########################################################################
 setMethodS3("getFitUnitGroupFunction", "MbeiPlm", function(this, ...) {
   # To help 'R CMD check' to locate fit.li.wong().
-  requireNamespace("affy") || throw("Package not loaded: affy");
+  requireNamespace("affy") || throw("Package not loaded: affy")
   fit.li.wong <- affy::fit.li.wong
 
 
-  standardize <- this$standardize;
-  shift <- this$shift;
+  standardize <- this$standardize
+  shift <- this$shift
   if (is.null(shift))
-    shift <- 0;
+    shift <- 0
 
   liWong <- function(y, priors=NULL, ...) {
     if (!is.null(priors)) {
-      throw("NOT IMPLEMENTED: Internal liWong() does not support prior parameters.");
+      throw("NOT IMPLEMENTED: Internal liWong() does not support prior parameters.")
     }
 
     # Add shift
-    y <- y + shift;
+    y <- y + shift
 
     # Enough of probes?
     if (nrow(y) > 1) {
-      fit <- fit.li.wong(t(y));
+      fit <- fit.li.wong(t(y))
 
       # A fit function must return: theta, sdTheta, thetaOutliers,
       # phi, sdPhi, phiOutliers.
-      names <- names(fit);
+      names <- names(fit)
       idxs <- match(c("sigma.theta", "theta.outliers", "sigma.phi",
-                                                     "phi.outliers"), names);
-      names[idxs] <- c("sdTheta", "thetaOutliers", "sdPhi", "phiOutliers");
-      names(fit) <- names;
+                                                     "phi.outliers"), names)
+      names[idxs] <- c("sdTheta", "thetaOutliers", "sdPhi", "phiOutliers")
+      names(fit) <- names
 
       # Rescale such that prod(phi) = 1?
       if (standardize) {
-        phi <- fit$phi;
-        theta <- fit$theta;
-        K <- length(phi);
-        c <- prod(phi)^(1/K);
-        phi <- phi/c;
-        theta <- theta*c;
-        fit$phi <- phi;
-        fit$theta <- theta;
+        phi <- fit$phi
+        theta <- fit$theta
+        K <- length(phi)
+        c <- prod(phi)^(1/K)
+        phi <- phi/c
+        theta <- theta*c
+        fit$phi <- phi
+        fit$theta <- theta
       }
     } else {
       # For the case where there is only a single probe in the unit group
@@ -231,43 +231,11 @@ setMethodS3("getFitUnitGroupFunction", "MbeiPlm", function(this, ...) {
                   phi=1, sdPhi=NA, phiOutliers=NA,
                   sigma.eps=NA, single.outliers=NA,
                   convergence1=NA, convergence2=NA,
-                  iter=1, delta=NA);
+                  iter=1, delta=NA)
     }
 
-    fit;
+    fit
   } # liWong()
 
-  liWong;
+  liWong
 }, protected=TRUE)
-
-
-
-############################################################################
-# HISTORY:
-# 2012-03-23
-# o Now getFitUnitGroupFunction() for MbeiPlm helps 'R CMD check' to
-#   locate fit.li.wong() by explicitly requiring 'affy'.
-# 2012-01-14
-# o ROBUSTNESS: Now the fit functions of RmaPlm and MbeiPlm give an
-#   error whenever trying to use prior parameters, which are yet
-#   not supported.
-# 2006-12-18
-# o Now the fit function of the MBEI model treats single-probe unit groups
-#   specially; the affy::fit.li.wong() handled it already before, but
-#   generated a warning for each call.
-# o BUG FIX: The encoding/decoding of probe affinities assumed at least two
-#   probes per unit group, but this is not true for all chip types, e.g.
-#   the 500K SNP chips.
-# 2006-09-10
-# o Updated getFitFunction() to return required fields.
-# 2006-08-24
-# o Added Rdoc comments.
-# 2006-08-23
-# o Added getProbeAffinities() and the corrsponding cached fields.
-# o Now fit() does not re-read data just updated.
-# 2006-08-19
-# o After all the bug fixes in updateCel() I think this function finally
-#   works correctly.
-# 2006-08-17
-# o Created.
-############################################################################
