@@ -29,29 +29,29 @@
 # @author "HB"
 #*/###########################################################################
 setConstructorS3("MultiArrayUnitModel", function(..., listOfPriors=NULL) {
-  this <- extend(UnitModel(...), "MultiArrayUnitModel");
+  this <- extend(UnitModel(...), "MultiArrayUnitModel")
   if (!is.null(listOfPriors)) {
-    this <- setListOfPriors(this, listOfPriors);
+    this <- setListOfPriors(this, listOfPriors)
   }
-  this;
+  this
 }, abstract=TRUE)
 
 
 setMethodS3("validate", "MultiArrayUnitModel", function(this, ...) {
-  ds <- getDataSet(this);
+  ds <- getDataSet(this)
   if (is.null(ds))
-    return(invisible(TRUE));
+    return(invisible(TRUE))
 
   if (length(ds) < 2) {
-    priors <- getListOfPriors(this);
-    hasPriors <- (!is.null(priors));
+    priors <- getListOfPriors(this)
+    hasPriors <- (!is.null(priors))
     if (!hasPriors) {
       throw("This ", class(this)[1], " requires at least 2 arrays: ",
-                                                            length(ds));
+                                                            length(ds))
     }
   }
 
-  invisible(TRUE);
+  invisible(TRUE)
 }, protected=TRUE)
 
 
@@ -81,13 +81,13 @@ setMethodS3("validate", "MultiArrayUnitModel", function(this, ...) {
 #   @seeclass
 # }
 #*/###########################################################################
-setMethodS3("getFitUnitGroupFunction", "MultiArrayUnitModel", abstract=TRUE, static=TRUE, private=TRUE);
+setMethodS3("getFitUnitGroupFunction", "MultiArrayUnitModel", abstract=TRUE, static=TRUE, private=TRUE)
 
 
 
 setMethodS3("getFitUnitFunction", "MultiArrayUnitModel", function(this, ...) {
   # Get the fit function for a single set of intensities
-  fitfcn <- getFitUnitGroupFunction(this, ...);
+  fitfcn <- getFitUnitGroupFunction(this, ...)
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Create the one for all blocks in a unit
@@ -97,7 +97,7 @@ setMethodS3("getFitUnitFunction", "MultiArrayUnitModel", function(this, ...) {
       lapply(unit, FUN=function(group) {
         y <- .subset2(group, 1); # Get intensities
         y <- y[1,,] - y[2,,];  # PM-MM
-        fitfcn(y, ...);
+        fitfcn(y, ...)
       })
     }
   } else if (this$probeModel == "min1(pm-mm)") {
@@ -106,7 +106,7 @@ setMethodS3("getFitUnitFunction", "MultiArrayUnitModel", function(this, ...) {
         y <- .subset2(group, 1); # Get intensities
         y <- y[1,,] - y[2,,];  # PM-MM
         y[y < 1] <- 1;       # min1(PM-MM)=min(PM-MM,1)
-        fitfcn(y, ...);
+        fitfcn(y, ...)
       })
     }
   } else if (this$probeModel == "pm+mm") {
@@ -114,7 +114,7 @@ setMethodS3("getFitUnitFunction", "MultiArrayUnitModel", function(this, ...) {
       lapply(unit, FUN=function(group) {
         y <- .subset2(group, 1); # Get intensities
         y <- y[1,,] + y[2,,];  # PM+MM
-        fitfcn(y, ...);
+        fitfcn(y, ...)
       })
     }
   } else {
@@ -123,14 +123,14 @@ setMethodS3("getFitUnitFunction", "MultiArrayUnitModel", function(this, ...) {
         if (length(group) > 0) {
           y <- .subset2(group, 1); # Get intensities
         } else {
-          y <- NULL;
+          y <- NULL
         }
-        fitfcn(y, ...);
+        fitfcn(y, ...)
       })
     }
   }
 
-  fitUnit;
+  fitUnit
 }, private=TRUE) # getFitUnitFunction()
 
 
@@ -173,53 +173,53 @@ setMethodS3("readUnits", "MultiArrayUnitModel", function(this, units=NULL, ...,
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
 
-  ds <- getDataSet(this);
-  verbose && enter(verbose, "Reading probe intensities from ", length(ds), " arrays");
+  ds <- getDataSet(this)
+  verbose && enter(verbose, "Reading probe intensities from ", length(ds), " arrays")
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Get the CDF cell indices
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  verbose && enter(verbose, "Identifying CDF cell indices");
-  cdfUnits <- getCellIndices(this, units=units, ...);
-  verbose && print(verbose, cdfUnits[1]);
-  verbose && exit(verbose);
+  verbose && enter(verbose, "Identifying CDF cell indices")
+  cdfUnits <- getCellIndices(this, units=units, ...)
+  verbose && print(verbose, cdfUnits[1])
+  verbose && exit(verbose)
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Get the CEL intensities by units
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  res <- getUnitIntensities(ds, units=cdfUnits, ...);
-  verbose && str(verbose, res[1]);
+  res <- getUnitIntensities(ds, units=cdfUnits, ...)
+  verbose && str(verbose, res[1])
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
 
-  res;
+  res
 }, private=TRUE)
 
 
 
 
 setMethodS3("getListOfPriors", "MultiArrayUnitModel", function(this, ...) {
-  this$.listOfPriors;
+  this$.listOfPriors
 })
 
 setMethodS3("setListOfPriors", "MultiArrayUnitModel", function(this, sets, ...) {
   # Arguments 'sets':
   if (!is.list(sets)) {
-    throw("Argument 'sets' is not a list: ", mode(sets)[1]);
+    throw("Argument 'sets' is not a list: ", mode(sets)[1])
   }
 
-  this$.listOfPriors <- sets;
+  this$.listOfPriors <- sets
 
-  invisible(this);
+  invisible(this)
 })
 
 
@@ -228,77 +228,57 @@ setMethodS3("readPriorsByUnits", "MultiArrayUnitModel", function(this, units=NUL
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
-  priorsList <- getListOfPriors(this);
-  nbrOfPriors <- length(priorsList);
+  priorsList <- getListOfPriors(this)
+  nbrOfPriors <- length(priorsList)
 
   # Nothing to do?
   if (nbrOfPriors == 0)
-    return(NULL);
+    return(NULL)
 
 
-  verbose && enter(verbose, "Reading prior parameters by unit");
+  verbose && enter(verbose, "Reading prior parameters by unit")
 
-  verbose && enter(verbose, "Reading prior parameters");
-  verbose && cat(verbose, "Number of parameter sets: ", nbrOfPriors);
-  res <- list();
+  verbose && enter(verbose, "Reading prior parameters")
+  verbose && cat(verbose, "Number of parameter sets: ", nbrOfPriors)
+  res <- list()
   for (kk in seq_len(nbrOfPriors)) {
-    priors <- priorsList[[kk]];
-    verbose && enter(verbose, sprintf("Prior set #%d ('%s') of %d", kk, getName(priors), length(priorsList)));
-    values <- readUnits(priors, units=units, ..., verbose=less(verbose, 1));
-    verbose && str(verbose, values[1]);
-    res[[kk]] <- values;
+    priors <- priorsList[[kk]]
+    verbose && enter(verbose, sprintf("Prior set #%d ('%s') of %d", kk, getName(priors), length(priorsList)))
+    values <- readUnits(priors, units=units, ..., verbose=less(verbose, 1))
+    verbose && str(verbose, values[1])
+    res[[kk]] <- values
     # Not needed anymore
-    values <- priors <- NULL;
-    verbose && exit(verbose);
+    values <- priors <- NULL
+    verbose && exit(verbose)
   } # for (kk ...)
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
   if (length(priorsList) > 0) {
-    unit <- vector("list", nbrOfPriors);
-    names(unit) <- names(priorsList);
-    unit0 <- unit;
+    unit <- vector("list", nbrOfPriors)
+    names(unit) <- names(priorsList)
+    unit0 <- unit
 
-    verbose && enter(verbose, "Merging prior parameters unit by unit");
-    unitNames <- names(res[[1]]);
-    res2 <- vector("list", length(unitNames));
-    names(res2) <- unitNames;
+    verbose && enter(verbose, "Merging prior parameters unit by unit")
+    unitNames <- names(res[[1]])
+    res2 <- vector("list", length(unitNames))
+    names(res2) <- unitNames
     for (uu in seq_along(res2)) {
-      unit <- unit0;
+      unit <- unit0
       for (kk in seq_len(nbrOfPriors)) {
-        unit[[kk]] <- res[[kk]][[uu]];
+        unit[[kk]] <- res[[kk]][[uu]]
       } # for (kk ...)
-      res2[[uu]] <- unit;
+      res2[[uu]] <- unit
     } # for (uu ...)
-    verbose && exit(verbose);
+    verbose && exit(verbose)
   }
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
-  res2;
+  res2
 }, private=TRUE)
-
-
-
-
-
-############################################################################
-# HISTORY:
-# 2012-01-14
-# o Now the fit function returned by getFitUnitFunction() for
-#   MultiArrayUnitModel passes '...'.
-# o Now validate() for MultiArrayUnitModel accepts single-array data sets,
-#   iff priors are set.
-# o Added argument 'listOfPriors' to MultiArrayUnitModel().
-# 2008-12-08
-# o Added readPriorsByUnits().
-# 2008-09-03
-# o Added getFitUnitGroupFunction() model, which is a better name than
-#   getFitFunction().
-# o Created from ProbeLevelModel.R.
-############################################################################
