@@ -70,94 +70,94 @@ setMethodS3("extractMatrix", "ParameterCelSet", function(this, units=NULL, ...,
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'units':
-  cdf <- getCdf(this);
-  ugcMap <- NULL;
+  cdf <- getCdf(this)
+  ugcMap <- NULL
 
   if (is.null(units)) {
-    nunits <- nbrOfUnits(cdf);
+    nunits <- nbrOfUnits(cdf)
   } else if (inherits(units, "UnitGroupCellMap")) {
-    ugcMap <- units;
-    units <- unique(ugcMap[,"unit"]);
+    ugcMap <- units
+    units <- unique(ugcMap[,"unit"])
   } else {
-    units <- Arguments$getIndices(units, max=nbrOfUnits(cdf));
-    nunits <- length(units);
+    units <- Arguments$getIndices(units, max=nbrOfUnits(cdf))
+    nunits <- length(units)
   }
 
   # Argument 'field':
   if (length(field) > 1)
-    field <- field[1];
+    field <- field[1]
 
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
 
   # Settings
-  gcArrayFrequency <- getOption(aromaSettings, "memory/gcArrayFrequency", 10);
+  gcArrayFrequency <- getOption(aromaSettings, "memory/gcArrayFrequency", 10)
 
-  verbose && enter(verbose, "Getting data for the array set");
+  verbose && enter(verbose, "Getting data for the array set")
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Get (unit, group, cell) map
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (is.null(ugcMap)) {
-    verbose && enter(verbose, "Getting (unit, group, cell) map");
-    ugcMap <- getUnitGroupCellMap(this, units=units, verbose=less(verbose));
-    verbose && exit(verbose);
+    verbose && enter(verbose, "Getting (unit, group, cell) map")
+    ugcMap <- getUnitGroupCellMap(this, units=units, verbose=less(verbose))
+    verbose && exit(verbose)
   }
-  ugcMap <- subset(ugcMap, ...);
+  ugcMap <- subset(ugcMap, ...)
 
   if (nrow(ugcMap) == 0)
-    throw("Nothing to return.");
+    throw("Nothing to return.")
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Allocate return array
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  arrayNames <- getNames(this);
-  nbrOfArrays <- length(arrayNames);
+  arrayNames <- getNames(this)
+  nbrOfArrays <- length(arrayNames)
   if (field %in% c("pixels")) {
-    naValue <- as.integer(NA);
+    naValue <- as.integer(NA)
   } else {
-    naValue <- as.double(NA);
+    naValue <- as.double(NA)
   }
-  df <- matrix(naValue, nrow=nrow(ugcMap), ncol=nbrOfArrays);
-  colnames(df) <- arrayNames;
+  df <- matrix(naValue, nrow=nrow(ugcMap), ncol=nbrOfArrays)
+  colnames(df) <- arrayNames
 
   # Garbage collect
-  gc <- gc();
-  verbose && print(verbose, gc);
+  gc <- gc()
+  verbose && print(verbose, gc)
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Get thetas from the samples
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  verbose && enter(verbose, "Retrieving sample thetas");
+  verbose && enter(verbose, "Retrieving sample thetas")
   for (aa in seq_len(nbrOfArrays)) {
-    verbose && printf(verbose, "Array %d,\n", aa);
-    cf <- this[[aa]];
+    verbose && printf(verbose, "Array %d,\n", aa)
+    cf <- this[[aa]]
     df[,aa] <- getDataFlat(cf, units=ugcMap, fields=field,
-                                            verbose=less(verbose))[,field];
+                                            verbose=less(verbose))[,field]
     if (aa %% gcArrayFrequency == 0) {
       # Garbage collect
-      gc <- gc();
-      verbose && print(verbose, gc);
+      gc <- gc()
+      verbose && print(verbose, gc)
     }
   } # for (aa in ...)
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
   # Drop singleton dimensions?
   if (drop) {
-    df <- drop(df);
+    df <- drop(df)
   }
 
   if (returnUgcMap)
-    attr(df, "unitGroupCellMap") <- ugcMap;
+    attr(df, "unitGroupCellMap") <- ugcMap
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
-  df;
+  df
 }) # extractMatrix()
 
 
@@ -206,96 +206,64 @@ setMethodS3("extractDataFrame", "ParameterCelSet", function(this, addNames=FALSE
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
 
-  verbose && enter(verbose, "Getting data for the array set");
+  verbose && enter(verbose, "Getting data for the array set")
   data <- extractMatrix(this, ..., returnUgcMap=TRUE,
-                                                   verbose=less(verbose, 1));
+                                                   verbose=less(verbose, 1))
 
-  ugcMap <- attr(data, "unitGroupCellMap");
-  attr(data, "unitGroupCellMap") <- NULL;
+  ugcMap <- attr(data, "unitGroupCellMap")
+  attr(data, "unitGroupCellMap") <- NULL
 
   # Garbage collect
-  gc <- gc();
-  verbose && print(verbose, gc);
+  gc <- gc()
+  verbose && print(verbose, gc)
 
   if (addUgcMap) {
-    verbose && enter(verbose, "Merging UGC map and extracted data");
-    ugcMap <- as.data.frame(ugcMap);
-    data <- cbind(ugcMap, data);
+    verbose && enter(verbose, "Merging UGC map and extracted data")
+    ugcMap <- as.data.frame(ugcMap)
+    data <- cbind(ugcMap, data)
 
     if (addNames) {
       # Garbage collect
-      gc <- gc();
-      verbose && print(verbose, gc);
+      gc <- gc()
+      verbose && print(verbose, gc)
     }
 
-    verbose && exit(verbose);
+    verbose && exit(verbose)
   }
 
   if (addNames) {
-    verbose && enter(verbose, "Appending unit and group names from CDF");
-    cdf <- getCdf(this);
+    verbose && enter(verbose, "Appending unit and group names from CDF")
+    cdf <- getCdf(this)
     verbose && cat(verbose, "CDF chip type: ",
-                                        getChipType(cdf, fullname=TRUE));
+                                        getChipType(cdf, fullname=TRUE))
     ugNames <- getUnitGroupNamesFromUgcMap(cdf, ugcMap=ugcMap,
-                                              verbose=less(verbose, 10));
+                                              verbose=less(verbose, 10))
     # Not needed anymore
-    cdf <- ugcMap <- NULL;
-    verbose && cat(verbose, "(unit, group) names: ");
-    verbose && str(verbose, ugNames);
+    cdf <- ugcMap <- NULL
+    verbose && cat(verbose, "(unit, group) names: ")
+    verbose && str(verbose, ugNames)
 
-    ugNames <- as.data.frame(ugNames);
-    data <- cbind(ugNames, data);
+    ugNames <- as.data.frame(ugNames)
+    data <- cbind(ugNames, data)
     # Not needed anymore
-    ugNames <- NULL;
+    ugNames <- NULL
 
-    verbose && exit(verbose);
+    verbose && exit(verbose)
   }
 
   # Drop singleton dimensions?
   if (drop) {
-    data <- drop(data);
+    data <- drop(data)
   }
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
-  data;
+  data
 }) # extractDataFrame()
-
-
-
-############################################################################
-# HISTORY:
-# 2012-11-20
-# o Added getParametersAsString() to ParameterCelSet.  Used to be in
-#   direct subclasses.
-# o Added getParameters() to ParameterCelSet, which calls ditto of
-#   the first file.  Used to be in direct subclasses.
-# 2008-07-20
-# o Updated the following methods to preallocate matrixes with the correct
-#   data type to avoid coercing later: extractMatrix().
-# 2008-07-16
-# o Added argument drop=FALSE to extractDataFrame().
-# 2008-07-09
-# o Added argument drop=FALSE to extractMatrix().
-# 2008-02-28
-# o Now argument 'units' also can be a UnitGroupCellMap.
-# 2008-02-22
-# o Created for the main purpose of putting extractMatrix() here, which
-#   is currently common for ChipEffectSet and FirmaSet.
-# o Moved extractDataFrame() from ChipEffectSet to ParameterCelSet.
-# 2008-02-12
-# o Added arguments 'addNames' and 'addUgcMap' to extractDataFrame().
-# 2008-02-05
-# o Created extractDataFrame() for ChipEffectSet.
-# 2007-05-26
-# o Updated the Rdocs for extractMatrix().
-# 2007-03-04
-# o Created extractMatrix().
-############################################################################
