@@ -35,10 +35,10 @@ setConstructorS3("SmoothMultiarrayModel", function(..., typoOfWeights=c("none",
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'typoOfWeights':
-  typoOfWeights <- match.arg(typoOfWeights);
+  typoOfWeights <- match.arg(typoOfWeights)
 
   # Argument 'bandwidth':
-  bandwidth <- Arguments$getDouble(bandwidth, range=c(1,Inf));
+  bandwidth <- Arguments$getDouble(bandwidth, range=c(1,Inf))
 
 
   extend(ChromosomalModel(..., tags=tags), "SmoothMultiarrayModel",
@@ -54,47 +54,47 @@ setConstructorS3("SmoothMultiarrayModel", function(..., typoOfWeights=c("none",
 
 setMethodS3("as.character", "SmoothMultiarrayModel", function(x, ...) {
   # To please R CMD check
-  this <- x;
+  this <- x
 
-  s <- NextMethod("as.character");
-  s <- c(s, sprintf("Kernel: %s", this$.kernel));
-  s <- c(s, sprintf("Bandwidth: %.2fkb", getBandwidth(this)/1e3));
-  s;
+  s <- NextMethod("as.character")
+  s <- c(s, sprintf("Kernel: %s", this$.kernel))
+  s <- c(s, sprintf("Bandwidth: %.2fkb", getBandwidth(this)/1e3))
+  s
 }, protected=TRUE)
 
 
 setMethodS3("getAsteriskTags", "SmoothMultiarrayModel", function(this, collapse=NULL, ...) {
-  classTag <- toupper(gsub("Model$", "", class(this)[1]));
-  weightsTag <- switch(this$.typoOfWeights, "1/s2"="w=s2inv", "");
-  kernelTag <- this$.kernel;
-  bandwidthTag <- sprintf("b=%d", getBandwidth(this));
-  tags <- c(classTag, weightsTag, kernelTag, bandwidthTag);
-  tags <- tags[nzchar(tags)];
+  classTag <- toupper(gsub("Model$", "", class(this)[1]))
+  weightsTag <- switch(this$.typoOfWeights, "1/s2"="w=s2inv", "")
+  kernelTag <- this$.kernel
+  bandwidthTag <- sprintf("b=%d", getBandwidth(this))
+  tags <- c(classTag, weightsTag, kernelTag, bandwidthTag)
+  tags <- tags[nzchar(tags)]
 
   # Collapse?
-  tags <- paste(tags, collapse=collapse);
+  tags <- paste(tags, collapse=collapse)
 
-  tags;
+  tags
 }, protected=TRUE)
 
 
 setMethodS3("getRootPath", "SmoothMultiarrayModel", function(this, ...) {
-  tag <- getAsteriskTags(this)[1];
-  sprintf("%sData", tolower(tag));
+  tag <- getAsteriskTags(this)[1]
+  sprintf("%sData", tolower(tag))
 }, protected=TRUE)
 
 
 setMethodS3("getBandwidth", "SmoothMultiarrayModel", function(this, ...) {
-  this$.bandwidth;
+  this$.bandwidth
 })
 
 setMethodS3("setBandwidth", "SmoothMultiarrayModel", function(this, bandwidth, ...) {
   # Argument 'bandwidth':
-  bandwidth <- Arguments$getDouble(bandwidth, range=c(1,Inf));
+  bandwidth <- Arguments$getDouble(bandwidth, range=c(1,Inf))
 
-  oldValue <- this$.bandwidth;
-  this$.bandwidth <- bandwidth;
-  invisible(oldValue);
+  oldValue <- this$.bandwidth
+  this$.bandwidth <- bandwidth
+  invisible(oldValue)
 })
 
 setMethodS3("getOutputTuple", "SmoothMultiarrayModel", function(this, ..., force=FALSE,  vebose=FALSE) {
@@ -102,24 +102,17 @@ setMethodS3("getOutputTuple", "SmoothMultiarrayModel", function(this, ..., force
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
-  outTuple <- this$.outTuple;
+  outTuple <- this$.outTuple
   if (force || is.null(outTuple)) {
-    outTuple <- createOutputTuple(this, force=force, verbose=less(verbose, 2));
-    this$.outTuple <- outTuple;
+    outTuple <- createOutputTuple(this, force=force, verbose=less(verbose, 2))
+    this$.outTuple <- outTuple
   }
 
-  outTuple;
+  outTuple
 })
-
-
-##############################################################################
-# HISTORY:
-# 2007-09-20
-# o Created.
-##############################################################################
