@@ -34,52 +34,52 @@ setConstructorS3("UnitModel", function(dataSet=NULL, probeModel=c("pm", "mm", "p
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'dataSet':
   if (!is.null(dataSet)) {
-    dataSet <- Arguments$getInstanceOf(dataSet, "AffymetrixCelSet");
+    dataSet <- Arguments$getInstanceOf(dataSet, "AffymetrixCelSet")
   }
 
   # Argument 'probeModel':
-  probeModel <- match.arg(probeModel);
+  probeModel <- match.arg(probeModel)
 
   # Argument 'shift':
-  shift <- Arguments$getDouble(shift, disallow=c("NA", "NaN", "Inf"));
+  shift <- Arguments$getDouble(shift, disallow=c("NA", "NaN", "Inf"))
 
 
   extend(Model(dataSet=dataSet, ...), "UnitModel",
     probeModel = probeModel,
     shift = shift
-  );
+  )
 }, abstract=TRUE)
 
 
 
 setMethodS3("getParameters", "UnitModel", function(this, ...) {
-  params <- NextMethod("getParameters");
-  params$probeModel <- this$probeModel;
-  params$shift <- this$shift;
-  params;
+  params <- NextMethod("getParameters")
+  params$probeModel <- this$probeModel
+  params$shift <- this$shift
+  params
 }, protected=TRUE)
 
 
 setMethodS3("getAsteriskTags", "UnitModel", function(this, collapse=NULL, ...) {
   # Returns 'U' (but allow for future extensions)
-  tags <- NextMethod("getAsteriskTags", collapse=NULL);
-  tags[1] <- "U";
+  tags <- NextMethod("getAsteriskTags", collapse=NULL)
+  tags[1] <- "U"
 
   # Add class-specific tags
-  shift <- as.integer(round(this$shift));
+  shift <- as.integer(round(this$shift))
   if (shift != 0) {
-    tags <- c(tags, sprintf("%+d", shift));
+    tags <- c(tags, sprintf("%+d", shift))
   }
-  probeModel <- this$probeModel;
+  probeModel <- this$probeModel
   if (probeModel != "pm") {
-    tags <- c(tags, probeModel);
+    tags <- c(tags, probeModel)
   }
 
   if (!is.null(collapse)) {
-    tags <- paste(tags, collapse=collapse);
+    tags <- paste(tags, collapse=collapse)
   }
 
-  tags;
+  tags
 }, protected=TRUE)
 
 
@@ -116,28 +116,28 @@ setMethodS3("getCellIndices", "UnitModel", function(this, ..., verbose=FALSE) {
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
 
   # Identify the type of probes to read
   stratifyBy <- switch(this$probeModel, "pm"="pm", "mm"="mm",
-                       "pm-mm"="pmmm", "min1(pm-mm)"="pmmm", "pm+mm"="pmmm");
+                       "pm-mm"="pmmm", "min1(pm-mm)"="pmmm", "pm+mm"="pmmm")
 
   # Get the CDF cell indices
-  ds <- getDataSet(this);
-  cdf <- getCdf(ds);
+  ds <- getDataSet(this)
+  cdf <- getCdf(ds)
 
-  verbose && enter(verbose, "Identifying CDF cell indices");
-  verbose && cat(verbose, "Stratify by: ", stratifyBy);
+  verbose && enter(verbose, "Identifying CDF cell indices")
+  verbose && cat(verbose, "Stratify by: ", stratifyBy)
   cells <- getCellIndices(cdf, ..., stratifyBy=stratifyBy,
-                                                      verbose=less(verbose));
-  verbose && exit(verbose);
+                                                      verbose=less(verbose))
+  verbose && exit(verbose)
 
-  cells;
+  cells
 }, private=TRUE)
 
 
@@ -166,43 +166,12 @@ setMethodS3("getCellIndices", "UnitModel", function(this, ..., verbose=FALSE) {
 #   @seeclass
 # }
 #*/###########################################################################
-setMethodS3("findUnitsTodo", "UnitModel", abstract=TRUE);
+setMethodS3("findUnitsTodo", "UnitModel", abstract=TRUE)
 
 
-setMethodS3("getFitUnitFunction", "UnitModel", abstract=TRUE, private=TRUE);
+setMethodS3("getFitUnitFunction", "UnitModel", abstract=TRUE, private=TRUE)
 
 
 setMethodS3("getFitSingleCellUnitFunction", "UnitModel", function(this, ...) {
-  NULL;
+  NULL
 }, protected=TRUE)
-
-
-############################################################################
-# HISTORY:
-# 2008-10-09
-# o Added getFitSingleCellUnitFunction().
-# 2008-09-05
-# o TYPO: The error message for argument 'dataSet' in UnitModel() returned
-#   multiple strings, one per class.
-# 2008-09-03
-# o CLEANUP: Moved the handling of 'probeModel' and 'shift'  to UnitModel
-#   from ProbeLevelModel
-# 2007-01-06
-# o Removed never-used setup() method.
-# 2007-01-01
-# o Created from former UnitGroupsModel with history as follows:
-# 2006-11-19
-# o Started to modify methods of this class to work similar to the
-#   QuantileNormalizer and AllelicCrosstalkCalibrator classes.
-# 2006-09-14
-# o Not cloning the data set anymore.  Each model is responsible for
-#   tranforming the data structure their way.  The advantage with this
-#   approach is that we can cache read data in the data set object.
-# 2006-08-28
-# o Added getLabel(), which defaults to getName(), and setLabel().
-# 2006-08-24
-# o Added some Rdoc comments.
-# 2006-08-17
-# o Created.
-
-############################################################################
