@@ -96,7 +96,7 @@ verbose && exit(verbose);
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
 srcFileTags <- list();
 srcFiles <- c(list(cdf), list(ptb));
-for (kk in seq(along=srcFiles)) {
+for (kk in seq_along(srcFiles)) {
   srcFile <- srcFiles[[kk]];
   tags <- list(
     filename=getFilename(srcFile), 
@@ -112,7 +112,7 @@ footer$createdBy <- list(
   fullname = fullname, 
   email = email
 );
-names(srcFileTags) <- sprintf("srcFile%d", seq(along=srcFileTags));
+names(srcFileTags) <- sprintf("srcFile%d", seq_along(srcFileTags));
 footer$srcFiles <- srcFileTags;
 writeFooter(acp, footer);
 
