@@ -1,30 +1,30 @@
 installPkg <- function(pkg, ...) {
   # Parse 'pkg'
-  pattern <- "^([^:]*):([^:]*)$";
+  pattern <- "^([^:]*):([^:]*)$"
   if (regexpr(pattern, pkg) != -1) {
-    repos <- gsub(pattern, "\\1", pkg);
-    pkg <- gsub(pattern, "\\2", pkg);
+    repos <- gsub(pattern, "\\1", pkg)
+    pkg <- gsub(pattern, "\\2", pkg)
   } else {
-    repos <- "CRAN";
+    repos <- "CRAN"
   }
 
   # Nothing to do?
-  if (isPackageInstalled(pkg)) return();
+  if (isPackageInstalled(pkg)) return()
 
   # Assert known repository
-  repos <- match.arg(repos, choices=c("CRAN", "BioC", "R-Forge"));
+  repos <- match.arg(repos, choices=c("CRAN", "BioC", "R-Forge"))
 
   tryCatch({
     if (repos == "CRAN") {
-      install.packages(pkg);
+      install.packages(pkg)
     } else if (repos == "BioC") {
-      source("http://www.bioconductor.org/biocLite.R");
-      biocLite(pkg, suppressUpdates=TRUE, ask=FALSE);
+      source("https://www.bioconductor.org/biocLite.R")
+      biocLite(pkg, suppressUpdates=TRUE, ask=FALSE)
     } else if (repos == "R-Forge") {
-      install.packages(pkg, repos="http://R-Forge.R-project.org");
+      install.packages(pkg, repos="https://R-Forge.R-project.org")
     }
   }, error = function(ex) {
-    print(ex);
+    print(ex)
   })
 } # installPkg()
 
