@@ -2,39 +2,39 @@
 # Allele-specific CRMAv2
 ##########################################################################
 future::plan("multiprocess")
-library("aroma.affymetrix");
-library("calmate");
-verbose <- Arguments$getVerbose(-8, timestamp=TRUE);
+library("aroma.affymetrix")
+library("calmate")
+verbose <- Arguments$getVerbose(-8, timestamp=TRUE)
 
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Setup
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-dataSet <- "GSE34754";
-chipType <- "Mapping250K_Nsp";
+dataSet <- "GSE34754"
+chipType <- "Mapping250K_Nsp"
 
-csR <- AffymetrixCelSet$byName(dataSet, chipType=chipType);
-print(csR);
+csR <- AffymetrixCelSet$byName(dataSet, chipType=chipType)
+print(csR)
 
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # AS-CRMAv2
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-dsNList <- doASCRMAv2(csR, verbose=verbose);
-print(dsNList);
+dsNList <- doASCRMAv2(csR, verbose=verbose)
+print(dsNList)
 
-dsN <- exportAromaUnitPscnBinarySet(dsNList);
-print(dsN);
+dsN <- exportAromaUnitPscnBinarySet(dsNList)
+print(dsN)
 
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # CalMaTe
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-cmt <- CalMaTeCalibration(dsNList);
-print(cmt);
+cmt <- CalMaTeCalibration(dsNList)
+print(cmt)
 
-dsCList <- process(cmt, verbose=verbose);
-print(dsCList);
+dsCList <- process(cmt, verbose=verbose)
+print(dsCList)
 
-dsC <- exportAromaUnitPscnBinarySet(dsCList);
-print(dsC);
+dsC <- exportAromaUnitPscnBinarySet(dsCList)
+print(dsC)
